@@ -6,7 +6,8 @@ from anipy_cli.misc import error
 from anipy_cli.player.players import Mpv, Vlc, Syncplay
 from anipy_cli.player.players.base import PlayerBase
 
-PlayerBaseType = TypeVar('PlayerBaseType', bound=PlayerBase)
+PlayerBaseType = TypeVar("PlayerBaseType", bound=PlayerBase)
+
 
 def get_player(rpc_client=None, player_override=None) -> PlayerBaseType:
     cfg = Config()
@@ -15,9 +16,9 @@ def get_player(rpc_client=None, player_override=None) -> PlayerBaseType:
 
     if not player_override:
         player = cfg.player_path
-    
+
     if player == "mpv" and cfg.reuse_mpv_window:
-        from anipy_cli.player.players import MpvControllable
+        from anipy_cli.player.players.mpv_contrl import MpvControllable
         return MpvControllable(rpc_client=rpc_client)
 
     if player in ("mpv", "mpvnet"):
